at 'house';

text q{
	You are at the front door.
};

next_page living_room => 'Enter the house';
